#
# spec file for package ghc-base-compat-batteries
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name base-compat-batteries
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.10.4
Release:        1.1
Summary:        Base-compat with extra batteries
License:        MIT
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-contravariant-devel
BuildRequires:  ghc-rpm-macros
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
Provides functions available in later versions of 'base' to a wider range of
compilers, without requiring you to use CPP pragmas in your code.

This package provides the same API as the
'<http://hackage.haskell.org/package/base-compat base-compat>' library, but
depends on compatibility packages (such as 'semigroups') to offer a wider
support window than 'base-compat', which has no dependencies. Most of the
modules in this library have the same names as in 'base-compat' to make it
easier to switch between the two. There also exist versions of each module with
the suffix '.Repl.Batteries', which are distinct from anything in
'base-compat', to allow for easier use in GHCi.

See
'<https://github.com/haskell-compat/base-compat/blob/master/base-compat/README.markdown#dependencies
here>' for a more comprehensive list of differences between 'base-compat' and
'base-compat-batteries'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGES.markdown README.markdown

%changelog
* Wed Jul 11 2018 psimons@suse.com
- Update base-compat-batteries to version 0.10.4.
  [#]# Changes in 0.10.4 [2018.07.03]
  - Add a `SafeHaskellSpec` test which ensures that certain modules (such as
    `Prelude.Compat`) can be imported in the presence of `Safe`.
  - This coincides with the `base-compat-0.10.4` release. Refer to the
    [`base-compat` changelog](https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown#changes-in-0104-20180703)
    for more details.
  [#]# Changes in 0.10.3 [2018.07.02]
  - This coincides with the `base-compat-0.10.3` release. Refer to the
    [`base-compat` changelog](https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown#changes-in-0103-20180702)
    for more details.
  [#]# Changes in 0.10.2 [2018.07.02]
  - Sync with `base-4.12`/GHC 8.6
  - Introduce the `Data.Functor.Contravariant.Compat` module, which
    reexports `Data.Functor.Contravariant` from `base` (if using GHC 8.6 or
    later) or the `contravariant` library (if using an earlier version of GHC).
  - This coincides with the `base-compat-0.10.2` release. Refer to the
    [`base-compat` changelog](https://github.com/haskell-compat/base-compat/blob/master/base-compat/CHANGES.markdown#changes-in-0102-20180702)
    for more details.
* Fri May 11 2018 psimons@suse.com
- Update base-compat-batteries to version 0.10.1.
  A more detailed change log is not available.
